//include cybiko stuff

#include "CyWin.h"

//include prototypes for standard dialogs

#include "StdDlg.c"
#include "MenuForm.c"
#include "FileListForm.c"
#include "ArchiveListForm.c"


////////////////////////////////////////////////////
//globals
////////////////////////////////////////////////////

//main module
struct module_t main_module;
//exit flag
bool exit_application;
//file name
char filename[40];
//resource name
char resname[40];
//saveas
char saveas[40];
//temp
char temp[40];
//archive
struct Archive archive;
//input file
struct FileInput* pfilein;
//output file
struct FileOutput fileout;
//data
int data;
//return code
long retcode;


////////////////////////////////////////////////////
//implementation
////////////////////////////////////////////////////

//main function
long main(int argc, char* argv[], bool start)
{
	//result
	int Result;

	//set quit flag to false
	exit_application=FALSE;

	//initialize main module
	init_module(&main_module);

	for(;;)
	{

		//show the file list form
		Result=FileListForm("Files","*.*",filename,main_module.m_process);

		//if quit received, break out of loop
		if(Result==MENUFORM_QUIT) break;

		//check for running app
		if(Result==FILELIST_RUN)
		{
			//execute program
			data=execute_module(filename,&retcode,0);
			//continue
			continue;
		}

		//cancel message
		if(Result==MENUFORM_CANCEL)
		{
			//check that user really wants to quit
			Result=MessageBox("Confirm Quit",str_Really_exit,mbQuit | mbCancel,main_module.m_process);

			//quit confirmed
			if(Result==mrQuit)
			{
				//quit
				return(0);
			}

			continue;
		}

		for(;;)
		{
			//archive list
			Result=ArchiveListForm(filename,filename,resname,main_module.m_process);

			//bad archive
			if(Result==ARCHIVEFORM_BADARCHIVE)
			{
				//show error message
				MessageBox("Error!","Bad Archive!",mbOk,main_module.m_process);

				//copy file name
				strcpy(saveas,filename);

				//get a filename
				Result=InputBox("",temp,mbOk|mbCancel,39,saveas,main_module.m_process);
				
				//cancel save as
				if(Result!=mrOk) break;

				//allocate input file
				pfilein=(struct FileInput*)malloc(sizeof(struct FileInput));
		
				//open the file
				FileInput_ctor_Ex(pfilein,filename);

				//construct output file
				FileOutput_ctor(&fileout);

				//open output file
				FileOutput_open(&fileout,saveas,TRUE);

				//copy file
				while(!FileInput_is_eof(pfilein))
				{
					//read in a byte
					data=FileInput_read_byte(pfilein);

					//write out a byte
					FileOutput_write_byte(&fileout,data);
				}

				//destroy output file
				FileOutput_dtor(&fileout,LEAVE_MEMORY);

				//destroy infile
				FileInput_dtor(pfilein,FREE_MEMORY);

				break;
			}

			//quit
			if(Result==MENUFORM_QUIT)
			{
				return(0);
			}

			//cancel
			if(Result==MENUFORM_CANCEL) break;

			//set up prompt
			sprintf(temp,"Save '%s' as...",resname);

			//copy string
			strcpy(saveas,resname);

			//get a filename
			Result=InputBox("",temp,mbOk|mbCancel,39,saveas,main_module.m_process);

			//check result
			if(Result==mrOk)
			{
				//export the file

				//turn on the hourglass
				set_hourglass(TRUE);
				
				//construct the archive
				Archive_ctor(&archive,filename);

				//open the file
				pfilein=Archive_open_Ex(&archive,resname);

				//construct output file
				FileOutput_ctor(&fileout);

				//open output file
				FileOutput_open(&fileout,saveas,TRUE);

				//copy file
				while(!FileInput_is_eof(pfilein))
				{
					//read in a byte
					data=FileInput_read_byte(pfilein);

					//write out a byte
					FileOutput_write_byte(&fileout,data);
				}

				//destroy output file
				FileOutput_dtor(&fileout,LEAVE_MEMORY);

				//destroy infile
				FileInput_dtor(pfilein,FREE_MEMORY);

				//destroy the archive
				Archive_dtor(&archive,LEAVE_MEMORY);

				//turn off hourglass
				set_hourglass(FALSE);

			}
		}

	}

	//done, return 0
	return 0; 
}

