#ifndef __ARCHIVELISTFORM_C__
#define __ARCHIVELISTFORM_C__

#include "ArchiveListForm.h"

struct cItem* cItem_CreateFromArchiveResource(struct Archive* parchive,int entry);

int ArchiveListForm(
	char* title,				//(in)title of the form
	char* filename,				//(in)archive filename
	char* resourcename,			//(out)resource name selected
	struct cWinApp* ptr_win_app	//(in)application pointer(main_module.m_process)
)
{
	//custom form (pointer only to save stack)
	struct cCustomForm* pCustomForm;
	//rectangle (pointer only)
	struct rect_t* pRect;
	//list(ptr)
	struct cList* pList;
	//item(ptr)
	struct cItem* pItem;
	//return value
	int Result;
	//message pointer
	struct Message* pMsg;
	//archive
	struct Archive* pArchive;
	//index
	int index;

	set_hourglass(TRUE);

	//allocate the archive
	pArchive=(struct Archive*)malloc(sizeof(struct Archive));

	//construct archive
	Archive_ctor(pArchive,filename);

	//check that archive is OK
	if(Archive_is_good(pArchive)==FALSE)
	{
		//turn off the hourglass
		set_hourglass(FALSE);
		//bad archive
		Archive_dtor(pArchive,FREE_MEMORY);
		//return error
		return(ARCHIVEFORM_BADARCHIVE);
	}

	//allocate
	pCustomForm=(struct cCustomForm*)malloc(sizeof(struct cCustomForm));

	//set up rectangle
	pRect=(struct rect_t*)malloc(sizeof(struct rect_t));
	rect_set(pRect,-2,-2,164,104);

	//construct
	cCustomForm_ctor(pCustomForm,pRect,title,FALSE,ptr_win_app);

	//allocate the list
	pList=(struct cList*)malloc(sizeof(struct cList));

	//construct the list
	cList_ctor(pList,158);

	//add items
	for(index=0;index<Archive_count_entries(pArchive);index++)
	{
		//new item
		pItem=cItem_CreateFromArchiveResource(pArchive,index);
		//add item
		cList_AddItem(pList,pItem);
	}

	//destroy archive
	Archive_dtor(pArchive,FREE_MEMORY);

	//add the list to the form
	cCustomForm_AddObj(pCustomForm,pList,0,0);

	//set the modal result to none
	pCustomForm->ModalResult=mrNone;

	//turn off the hourglass
	set_hourglass(FALSE);

	//message loop
	while(pCustomForm->ModalResult==mrNone)
	{
		//show form
		cCustomForm_Show(pCustomForm);

		//get a message
		pMsg=cWinApp_get_message(ptr_win_app,0,1,MSG_USER);

		switch(pMsg->msgid)
		{
		case MSG_QUIT:
		case MSG_SHUTUP:
			{
				//return a -2
				Result=MENUFORM_QUIT;
				//change the modal result
				pCustomForm->ModalResult=mrQuit;
			}break;
		case MSG_KEYDOWN:
			{
				//check for esc
				if(Message_get_key_param(pMsg)->scancode==KEY_ESC)
				{
					//result of -1
					Result=MENUFORM_CANCEL;
					//change modalresult
					pCustomForm->ModalResult=mrCancel;
					break;
				}
				//check for enter
				if(Message_get_key_param(pMsg)->scancode==KEY_ENTER)
				{
					//result of selected item
					Result=cList_Sel(pList);
					//get item
					pItem=cList_get_by_index(pList,Result);
					//copy name to filename
					strcpy(resourcename,cItem_GetTitle(pItem));
					//change modalresult
					pCustomForm->ModalResult=mrOk;
					break;
				}
			}
		default:
			//default processing
			cCustomForm_proc(pCustomForm,pMsg);
		}

		//delete the message
		Message_delete(pMsg);
	}

	//hide form
	cCustomForm_Hide(pCustomForm);

	//clear out the list
	while(cList_GetCount(pList)>0)
	{
		//grab first item
		pItem=cList_get_by_index(pList,0);
		//remove item
		cList_RemObj(pList,pItem);
		//destroy item
		cItem_dtor(pItem,FREE_MEMORY);
	}

	//remove list from form
	cCustomForm_RemObj(pCustomForm,pList);

	//destroy list
	cList_dtor(pList,FREE_MEMORY);

	//destroy form
	cCustomForm_dtor(pCustomForm,FREE_MEMORY);

	//destroy rect
	free(pRect);

	//return the result
	return(Result);
}

struct cItem* cItem_CreateFromArchiveResource(struct Archive* parchive,int entry)
{
	struct cItem* pItem;
	//allocate a new item
	pItem=(struct cItem*)malloc(sizeof(struct cItem));
	//construct item
	cItem_ctor(pItem,158,Archive_get_name(parchive,entry),FALSE,NULL,NULL);
	//return the new item
	return(pItem);
}


#endif